# API Documentation

Welcome to the API documentation for rxiv-maker.

## Core Modules

- [__version__.py](__version__.py.md)
- [core.cache.cache_utils.py](cache_utils.py.md)
- [core.error_codes.py](error_codes.py.md)
- [core.logging_config.py](logging_config.py.md)
- [engines.operations.validate.py](validate.py.md)
- [manuscript_utils.figure_utils.py](figure_utils.py.md)
- [utils.citation_utils.py](citation_utils.py.md)
- [utils.email_encoder.py](email_encoder.py.md)
- [utils.operation_ids.py](operation_ids.py.md)
- [utils.platform.py](platform.py.md)
- [utils.python_execution_reporter.py](python_execution_reporter.py.md)
- [utils.text_utils.py](text_utils.py.md)
- [utils.unicode_safe.py](unicode_safe.py.md)
- [utils.url_to_doi.py](url_to_doi.py.md)
- [validate.py](validate.py.md)

